@@ -1,8 +1,9 @@
-import click
 import git
+import click
+
 from gitutor.init.commands import init
 from gitutor.save.commands import save
-
+from gitutor.ignore.commands import ignore
 
 @click.group()
 @click.pass_context
@@ -24,6 +25,7 @@ def cli(ctx):
 
 cli.add_command(init)
 cli.add_command(save)
+cli.add_command(ignore)
 
 def main():
     cli(obj={})
