@@ -46,10 +46,7 @@ def init(ctx, user_name, password,local, repo_name):
         local_repo = init_local_repo()
         local_repo.create_remote('origin', remote_repo.clone_url)
         click.echo('Push to origin...')
-        try:
-            local_repo.git.push('-u', 'origin', 'master')
-        except GitCommandError:
-            click.echo("Git command error detected")
+        local_repo.git.push('-u', 'origin', 'master')
         click.echo('Ready!')
 
 def init_local_repo():
