@@ -43,10 +43,8 @@ def save(ctx, message, push):
                             click.echo("- " + conflict_file)
                         click.echo('Please fix conflicts then use "gt save -p" again')    
                 else:
-                    try:
-                        repo.git.push()
-                    except GitCommandError:
-                        click.echo("Git command error detected")
+                    repo.git.push()
+
 
             else:
                 click.echo('Remote repository does not exist!')
